aboutsummaryrefslogtreecommitdiff
path: root/talk/app/webrtc/objc/public/RTCFileLogger.h
diff options
context:
space:
mode:
authortkchin <tkchin@webrtc.org>2015-07-23 12:27:02 -0700
committerCommit bot <commit-bot@chromium.org>2015-07-23 19:27:06 +0000
commit28bae02bd383abbd35cc87fa1188a569f1b3c683 (patch)
treeb1584bb2e5e4ecb6d4c3336fdcec2041d025b57b /talk/app/webrtc/objc/public/RTCFileLogger.h
parent3ab2f14d56db91665002f36f899c0a97f926d91f (diff)
downloadwebrtc-28bae02bd383abbd35cc87fa1188a569f1b3c683.tar.gz
Remove CircularFileStream / replace it with CallSessionFileRotatingStream.
BUG=4838, 4839 Review URL: https://codereview.webrtc.org/1245143005 Cr-Commit-Position: refs/heads/master@{#9628}
Diffstat (limited to 'talk/app/webrtc/objc/public/RTCFileLogger.h')
-rw-r--r--talk/app/webrtc/objc/public/RTCFileLogger.h18
1 files changed, 8 insertions, 10 deletions
diff --git a/talk/app/webrtc/objc/public/RTCFileLogger.h b/talk/app/webrtc/objc/public/RTCFileLogger.h
index 5c311b711a..3900cb6fbe 100644
--- a/talk/app/webrtc/objc/public/RTCFileLogger.h
+++ b/talk/app/webrtc/objc/public/RTCFileLogger.h
@@ -49,24 +49,22 @@ typedef NS_ENUM(NSUInteger, RTCFileLoggerSeverity) {
// The severity level to capture. The default is kRTCFileLoggerSeverityInfo.
@property(nonatomic, assign) RTCFileLoggerSeverity severity;
-// Default constructor provides default settings for file path and file size.
+// Default constructor provides default settings for dir path and file size.
- (instancetype)init;
-- (instancetype)initWithFilePath:(NSString *)filePath
- maxFileSize:(NSUInteger)maxFileSize
+- (instancetype)initWithDirPath:(NSString *)dirPath
+ maxFileSize:(NSUInteger)maxFileSize
NS_DESIGNATED_INITIALIZER;
-// Starts writing WebRTC logs to file if not already started. Overwrites any
-// existing file.
+// Starts writing WebRTC logs to disk if not already started. Overwrites any
+// existing file(s).
- (void)start;
-// Stops writing WebRTC logs to file. Rewrites the log file as required to
-// reorder logs because logs may be disordered due to use of
-// rtc::CircularFileStream. This method is also called on dealloc.
+// Stops writing WebRTC logs to disk. This method is also called on dealloc.
- (void)stop;
-// Returns the current contents of the log file. Returns nil if start has been
-// called without a stop, or if there is no data.
+// Returns the current contents of the logs, or nil if start has been called
+// without a stop.
- (NSData *)logData;
@end